Demonstration of CodeMirrors Java highlighter written by Patrick Wied

Demonstration of CodeMirror's Java highlighter.

Written by Patrick Wied.

package example; import java.awt.*; /** * This class subclasses DrawableRect and adds colors to the rectangle it draws **/ public class ColoredRect extends DrawableRect { // These are new fields defined by this class. // x1, y1, x2, and y2 are inherited from our super-superclass, Rect. @AnnotationTest protected Color border, fill; private String name; /** * This constructor uses super() to invoke the superclass constructor, and * also does some initialization of its own. **/ public ColoredRect(int x1, int y1, int x2, int y2, Color border, Color fill){ super(x1, y1, x2, y2); /* This is a block comment */ this.border = border; this.fill = fill; this.name = "This is a string"; } /** * This method overrides the draw() method of our superclass so that it * can make use of the colors that have been specified. **/ public void draw(Graphics g) { g.setColor(fill); g.fillRect(x1, y1, x2, y2); g.setColor(border); g.drawRect(x1, y1, x2, y2); } }